@@ -26,6 +26,52 @@ class TeoClient(AbstractClient):
     _service = 'teo'
 
 
+    def BindSecurityTemplateToEntity(self, request):
+        """操作安全策略模板，支持将域名绑定或换绑到指定的策略模板，或者从指定的策略模板解绑。
+
+        :param request: Request instance for BindSecurityTemplateToEntity.
+        :type request: :class:`tencentcloud.teo.v20220901.models.BindSecurityTemplateToEntityRequest`
+        :rtype: :class:`tencentcloud.teo.v20220901.models.BindSecurityTemplateToEntityResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("BindSecurityTemplateToEntity", params, headers=headers)
+            response = json.loads(body)
+            model = models.BindSecurityTemplateToEntityResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def BindSharedCNAME(self, request):
+        """用于加速域名绑定或解绑共享 CNAME，该功能白名单内测中。
+
+        :param request: Request instance for BindSharedCNAME.
+        :type request: :class:`tencentcloud.teo.v20220901.models.BindSharedCNAMERequest`
+        :rtype: :class:`tencentcloud.teo.v20220901.models.BindSharedCNAMEResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("BindSharedCNAME", params, headers=headers)
+            response = json.loads(body)
+            model = models.BindSharedCNAMEResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def BindZoneToPlan(self, request):
         """将未绑定套餐的站点绑定到已有套餐
 
@@ -167,7 +213,7 @@ class TeoClient(AbstractClient):
 
 
     def CreateOriginGroup(self, request):
-        """创建源站组
+        """创建源站组，以源站组的方式管理业务源站。此处配置的源站组可于**添加加速域名**和**四层代理**等功能中引用。
 
         :param request: Request instance for CreateOriginGroup.
         :type request: :class:`tencentcloud.teo.v20220901.models.CreateOriginGroupRequest`
@@ -307,7 +353,7 @@ class TeoClient(AbstractClient):
 
 
     def CreateSharedCNAME(self, request):
-        """创建共享 CNAME
+        """用于创建共享 CNAME，该功能白名单内测中。
 
         :param request: Request instance for CreateSharedCNAME.
         :type request: :class:`tencentcloud.teo.v20220901.models.CreateSharedCNAMERequest`
@@ -515,6 +561,29 @@ class TeoClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteSharedCNAME(self, request):
+        """用于删除共享 CNAME，该功能白名单内测中。
+
+        :param request: Request instance for DeleteSharedCNAME.
+        :type request: :class:`tencentcloud.teo.v20220901.models.DeleteSharedCNAMERequest`
+        :rtype: :class:`tencentcloud.teo.v20220901.models.DeleteSharedCNAMEResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteSharedCNAME", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteSharedCNAMEResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteZone(self, request):
         """删除站点。
 
@@ -838,7 +907,7 @@ class TeoClient(AbstractClient):
 
 
     def DescribeOverviewL7Data(self, request):
-        """本接口（DescribeOverviewL7Data）用于查询七层监控类时序流量数据。
+        """本接口（DescribeOverviewL7Data）用于查询七层监控类时序流量数据。此接口待废弃，请使用 <a href="https://cloud.tencent.com/document/product/1552/80648">DescribeTimingL7AnalysisData</a> 接口。
 
         :param request: Request instance for DescribeOverviewL7Data.
         :type request: :class:`tencentcloud.teo.v20220901.models.DescribeOverviewL7DataRequest`
@@ -861,7 +930,7 @@ class TeoClient(AbstractClient):
 
 
     def DescribePrefetchTasks(self, request):
-        """查询预热任务状态
+        """DescribePrefetchTasks 用于查询预热任务提交历史记录及执行进度，通过 CreatePrefetchTasks 接口提交的任务可通过此接口进行查询。
 
         :param request: Request instance for DescribePrefetchTasks.
         :type request: :class:`tencentcloud.teo.v20220901.models.DescribePrefetchTasksRequest`
@@ -884,7 +953,7 @@ class TeoClient(AbstractClient):
 
 
     def DescribePurgeTasks(self, request):
-        """查询清除缓存历史记录
+        """DescribePurgeTasks 用于查询提交的 URL 刷新、目录刷新记录及执行进度，通过 CreatePurgeTasks 接口提交的任务均可通过此接口进行查询。
 
         :param request: Request instance for DescribePurgeTasks.
         :type request: :class:`tencentcloud.teo.v20220901.models.DescribePurgeTasksRequest`
@@ -952,6 +1021,29 @@ class TeoClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeSecurityTemplateBindings(self, request):
+        """查询指定策略模板的绑定关系列表。
+
+        :param request: Request instance for DescribeSecurityTemplateBindings.
+        :type request: :class:`tencentcloud.teo.v20220901.models.DescribeSecurityTemplateBindingsRequest`
+        :rtype: :class:`tencentcloud.teo.v20220901.models.DescribeSecurityTemplateBindingsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSecurityTemplateBindings", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSecurityTemplateBindingsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeTimingL4Data(self, request):
         """本接口（DescribeTimingL4Data）用于查询四层时序流量数据列表。
 
@@ -1392,7 +1484,7 @@ class TeoClient(AbstractClient):
 
 
     def ModifyOriginGroup(self, request):
-        """修改源站组
+        """修改源站组配置，新提交的源站记录将会覆盖原有源站组中的源站记录。
 
         :param request: Request instance for ModifyOriginGroup.
         :type request: :class:`tencentcloud.teo.v20220901.models.ModifyOriginGroupRequest`
